#! /usr/bin/env node
"use strict";

var _eslint = require("eslint");

var _chalk = _interopRequireDefault(require("chalk"));

var _fs = require("fs");

var _path = _interopRequireDefault(require("path"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * Get human friendly label for severity
 * @param severity - sevrity
 * @returns sevrity label
 */
function getSeverityLabel(severity) {
  switch (severity) {
    case 1:
      return 'warning';

    case 2:
      return 'error';

    default:
      return 'unknown';
  }
}
/**
 * Print path to file as part of linting results
 * @param filePath - path to file
 */


function printFilePath(filePath) {
  var relativeFilePath = filePath.replace(process.cwd(), '').replace(/^\//, '');

  var underlinedText = _chalk["default"].underline(relativeFilePath);

  console.log(underlinedText);
}
/**
 * Print path to file as part of linting results
 * @param line - line in which linting issue occurs
 * @param column - column in which linting issue occurs
 * @param severity - severity of linting issue ("error" or "warning")
 * @param message - linting message
 * @param rule - linting rule
 */


function printLintItem(line, column, severity, message, rule) {
  var position = _chalk["default"].dim(line + ":" + column);

  rule = _chalk["default"].dim(rule);

  if (severity === 'error') {
    severity = _chalk["default"].red(severity);
  } else {
    severity = _chalk["default"].yellow(severity);
  }

  console.log("  " + position + "  " + severity + "  " + message + "  " + rule);
}
/**
 * Print summary of linting results for a particular linter/file type
 * @param label - label for summary (language being linted)
 * @param errors - error count
 * @param warnings - warning count
 */


function printLintSummary(label, errors, warnings) {
  var text = " " + label + ": " + errors + " errors, " + warnings + " warnings ";
  var coloredText;

  if (errors) {
    coloredText = _chalk["default"].white(_chalk["default"].bgRed(text));
  } else if (warnings) {
    coloredText = _chalk["default"].bgYellow(text);
  } else {
    coloredText = _chalk["default"].bgGreen(text);
  }

  var boldColoredText = _chalk["default"].bold(coloredText);

  console.log(boldColoredText + "\n");
}

var CWD = process.cwd();
var CWD_FILES = (0, _fs.readdirSync)(CWD);
var CONFIG_FILE = CWD_FILES.find(function (fileName) {
  return /^\.eslintrc(\.[a-zA-Z]+)?$/.test(fileName);
});
var cli = new _eslint.CLIEngine({
  configFile: CONFIG_FILE || _path["default"].join(__dirname, 'config.js')
});
var files = process.argv.slice(2);

var _cli$executeOnFiles = cli.executeOnFiles(files),
    errorCount = _cli$executeOnFiles.errorCount,
    results = _cli$executeOnFiles.results,
    warningCount = _cli$executeOnFiles.warningCount;

results.forEach(function (_ref) {
  var filePath = _ref.filePath,
      messages = _ref.messages;
  if (!messages.length) return;
  printFilePath(filePath);
  messages.forEach(function (_ref2) {
    var column = _ref2.column,
        line = _ref2.line,
        message = _ref2.message,
        ruleId = _ref2.ruleId,
        severity = _ref2.severity;
    printLintItem(line, column, getSeverityLabel(severity), message.replace(/\.$/, ''), ruleId);
  });
  console.log(''); // logging empty line
});
printLintSummary('Javascript', errorCount, warningCount);

if (errorCount) {
  process.exit(1);
}